@@ -103,6 +103,10 @@ class ArtifactAPI(BaseAPI):
         cs_refs = [cs._ref for cs in tags]
         self._add_members_refs_to_collection(artifact._ref, cs_refs, "tags")
 
+    def remove_tags_from_artifact(self, artifact: Artifact, tags: List[RallyTypeGeneric]):
+        cs_refs = [cs._ref for cs in tags]
+        self._delete_members_refs_from_collection(artifact._ref, cs_refs, "tags")
+
     def add_changesets_to_artifact(self, artifact: Artifact, changesets: List[RallyTypeGeneric]):
         cs_refs = [cs._ref for cs in changesets]
         self._add_members_refs_to_collection(artifact._ref, cs_refs, "changesets")
